@@ -13,6 +13,7 @@
 #' @param avg Either the string 'all', or the averaging interval to download, in minutes. Only applicable to sensor (IS) data. Defaults to 'all'.
 #' @param check.size T or F, should the user be told the total file size before downloading? Defaults to T. When working in batch mode, or other non-interactive workflow, use check.size=F.
 #' @param savepath The location to save the output files to
+#' @param load T or F, are files saved locally or loaded directly? Used silently with loadByProduct(), do not set manually.
 
 #' @return A folder in the working directory (or in savepath, if specified), containing all zip files meeting query criteria.
 
@@ -33,7 +34,7 @@
 ##############################################################################################
 
 zipsByProduct <- function(dpID, site="all", package="basic", avg="all", 
-                          check.size=TRUE, savepath=NA) {
+                          check.size=TRUE, savepath=NA, load=F) {
 
   messages <- NA
   
@@ -116,16 +117,17 @@ zipsByProduct <- function(dpID, site="all", package="basic", avg="all",
 
     # check for no files
     if(length(tmp.files$data$files)==0) {
-      messages <- c(messages, paste("No files found for site", tmp.files$data$siteCode,
-                                    "and month", tmp.files$data$month, sep=" "))
+      messages <- c(messages, paste("No files found for site", substring(month.urls[i], 58, 61),
+                                    "and month", substring(month.urls[i], 63, 69), sep=" "))
       next
     }
     
-    # if only one averaging interval is requested, divert to filesByAvg()
+    # if only one averaging interval is requested, filter by file names
     if(avg!="all") {
       
       # select files by averaging interval
-      all.file <- grep(paste(avg, "min", sep=""), tmp.files$data$files$name, fixed=T)
+      all.file <- union(grep(paste(avg, "min", sep=""), tmp.files$data$files$name, fixed=T),
+                        grep(paste(avg, "_min", sep=""), tmp.files$data$files$name, fixed=T))
       
       if(length(all.file)==0) {
         messages <- c(messages, paste("No files found for site", tmp.files$data$siteCode,
@@ -149,7 +151,10 @@ zipsByProduct <- function(dpID, site="all", package="basic", avg="all",
       
       # subset to package
       which.file <- intersect(grep(pk, tmp.files$data$files$name, fixed=T),
-                             grep(paste(avg, "min", sep=""), tmp.files$data$files$name, fixed=T))
+                             union(grep(paste(avg, "min", sep=""), 
+                                        tmp.files$data$files$name, fixed=T), 
+                                   grep(paste(avg, "_min", sep=""), 
+                                        tmp.files$data$files$name, fixed=T)))
       
       # check again for no files
       if(length(which.file)==0) {
@@ -163,11 +168,19 @@ zipsByProduct <- function(dpID, site="all", package="basic", avg="all",
                                         tmp.files$data$files$url[which.file],
                                         tmp.files$data$files$size[which.file]))
       
-      # add url for one copy of variables file
-      which.var <- grep("variables", tmp.files$data$files$name, fixed=T)[1]
-      zip.urls <- rbind(zip.urls, cbind(tmp.files$data$files$name[which.var],
-                                        tmp.files$data$files$url[which.var],
-                                        tmp.files$data$files$size[which.var]))
+      # add url for one copy of variables file and readme file
+      if(i==1) {
+        which.var <- grep("variables", tmp.files$data$files$name, fixed=T)[1]
+        zip.urls <- rbind(zip.urls, cbind(tmp.files$data$files$name[which.var],
+                                          tmp.files$data$files$url[which.var],
+                                          tmp.files$data$files$size[which.var]))
+        
+        # commented out - readme still needs general solution, they are specific to a site-month
+        # which.read <- grep("readme", tmp.files$data$files$name, fixed=T)[1]
+        # zip.urls <- rbind(zip.urls, cbind(tmp.files$data$files$name[which.read],
+        #                                   tmp.files$data$files$url[which.read],
+        #                                   tmp.files$data$files$size[which.read]))
+      }
       
     } else {
       
@@ -249,13 +262,22 @@ zipsByProduct <- function(dpID, site="all", package="basic", avg="all",
   }
   dir.create(filepath)
 
+  writeLines(paste("Downloading ", nrow(zip.urls)-1, " files", sep=""))
+  pb <- utils::txtProgressBar(style=3)
+  utils::setTxtProgressBar(pb, 1/(nrow(zip.urls)-1))
   # copy zip files into folder
   for(i in 2:nrow(zip.urls)) {
-    downloader::download(zip.urls$URL[i], paste(filepath, zip.urls$name[i], sep="/"), mode="wb")
+    downloader::download(zip.urls$URL[i], paste(filepath, zip.urls$name[i], sep="/"), 
+                         mode="wb", quiet=T)
+    utils::setTxtProgressBar(pb, i/(nrow(zip.urls)-1))
   }
+  utils::setTxtProgressBar(pb, 1)
+  close(pb)
 
-  messages <- c(messages, paste(nrow(zip.urls)-1, "files downloaded to",
-                                filepath, sep=" "))
+  if(load==F) {
+    messages <- c(messages, paste(nrow(zip.urls)-1, "files downloaded to",
+                                  filepath, sep=" "))
+  }
   writeLines(paste0(messages[-1], collapse = "\n"))
 
 }
